==> stream_1.1-1.tar.gz: stream/R/DSC_Micro.R <==
#######################################################################
# stream -  Infrastructure for Data Stream Mining
# Copyright (C) 2013 Michael Hahsler, Matthew Bolanos, John Forrest 
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.


### Subclasses need to implement methods for:
# Constructor
# method cluster for RObj
# get_microclusters(x)
# get_microweights(x)
########

DSC_Micro <- function(...) stop("DSC_Micro is an abstract class and cannot be instantiated!")


get_centers.DSC_Micro <- function(x, type=c("auto", "micro", "macro"), ...) {
    type <- match.arg(type)
    if(type=="auto") type <- "micro"

    if(type=="macro") return(get_macroclusters(x, ...))
    else return(get_microclusters(x, ...))
}


get_weights.DSC_Micro <- function(x, type=c("auto", "micro", "macro"),
	scale=NULL, ...) {
    type <- match.arg(type)
    if(type=="auto") type <- "micro"

    if(type=="macro") w <- get_macroweights(x, ...)
    else w <- get_microweights(x, ...)


    if(!is.null(scale)) { 
	if(length(unique(w)) ==1)  w <- rep(mean(scale), length(w))
	else w <- map(w, range=scale, from.range=c(0,  
			    max(w, na.rm=TRUE))) 
    }
    
    w
}

==> stream_1.5-1.tar.gz: stream/R/DSC_Micro.R <==
#######################################################################
# stream -  Infrastructure for Data Stream Mining
# Copyright (C) 2013 Michael Hahsler, Matthew Bolanos, John Forrest
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.


### Subclasses need to implement methods for:
# Constructor
# method cluster for RObj
# get_microclusters(x)
# get_microweights(x)
########



#' Abstract Class for Micro Clusterers
#'
#' Abstract class for all DSC Micro Clusterers.
#'
#' `DSC_Micro` cannot be instantiated.
#'
#' @param ... further arguments.
#' @author Michael Hahsler
#' @seealso [DSC]
#' @export DSC_Micro
DSC_Micro <- abstract_class_generator("DSC")

get_centers.DSC_Micro <- function(x, type=c("auto", "micro", "macro"), ...) {
    type <- match.arg(type)
    if(type=="auto") type <- "micro"

    if(type=="macro") return(get_macroclusters(x, ...))
    else return(get_microclusters(x, ...))
}


get_weights.DSC_Micro <- function(x, type=c("auto", "micro", "macro"),
	scale=NULL, ...) {
    type <- match.arg(type)
    if(type=="auto") type <- "micro"

    if(type=="macro") w <- get_macroweights(x, ...)
    else w <- get_microweights(x, ...)


    if(!is.null(scale)) {
	if(length(unique(w)) ==1)  w <- rep(mean(scale), length(w))
	else w <- map(w, range=scale, from.range=c(0,
			    max(w, na.rm=TRUE)))
    }

    w
}
